#!/bin/bash

# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0

echo -e "\e[1;32mTo start with sigopt generate token with the below mentioned link \e[0m"
echo -e "\e[1;36mIf you dont have account, create new account and sign and follow the steps mentioned to use sigopt \e[0m"
echo -e "\e[1;36mhttps://docs.sigopt.com/tutorial/experiment \e[0m"

sigopt config
